@@ -22,16 +22,36 @@ import requests
 from .renderer.excel import ExcelRenderer
 from .models import Session, AnalysisRun, AnalysisSend
 from .constants import DATETIME_FORMAT
-
+logger = logging.getLogger(__name__)
 
 BASE_API_URL = os.getenv('DATA_API_BASE_URL', '')
-AWS_ACCESS_KEY_ID = os.getenv('AWS_ACCESS_KEY_ID')
-AWS_SECRET_ACCESS_KEY = os.getenv('AWS_SECRET_ACCESS_KEY')
-REGION_NAME = os.getenv('REGION_NAME')
-S3_BUCKET_NAME = os.getenv('S3_BUCKET_NAME')
 API_RETRY = int(os.getenv('API_RETRY', 3))
 API_KEY = os.getenv('API_KEY')
 API_SECRET = os.getenv('API_SECRET')
+BASE_API_URL = os.getenv('DATA_API_BASE_URL', '')
+ROUTE = os.getenv("PLATFORM_ROUTE")
+
+storage_name = os.getenv('STORAGE_NAME')
+
+global ACCESS_KEY_ID, SECRET_ACCESS_KEY, REGION_NAME, BUCKET_NAME
+ACCESS_KEY_ID = ''
+SECRET_ACCESS_KEY = ''
+REGION_NAME = ''
+BUCKET_NAME = ''
+
+if storage_name == 's3_storage':
+    ACCESS_KEY_ID = os.getenv('AWS_ACCESS_KEY_ID')
+    SECRET_ACCESS_KEY = os.getenv('AWS_SECRET_ACCESS_KEY')
+    REGION_NAME = os.getenv('REGION_NAME')
+    BUCKET_NAME = os.getenv('S3_BUCKET_NAME')
+elif storage_name == 'ceph_storage':
+    ACCESS_KEY_ID = os.getenv('CEPH_ACCESS_KEY_ID')
+    SECRET_ACCESS_KEY = os.getenv('CEPH_SECRET_ACCESS_KEY')
+    BUCKET_NAME = os.getenv('CEPH_BUCKET_NAME')
+    REGION_NAME = os.getenv('CEPH_REGION_NAME')
+else:
+    logger.info("No storages are found")
+
 
 def get_token():
     headers = {"Content-Type" : "application/x-www-form-urlencoded" , "Accept" : "application/json"};
@@ -88,6 +108,10 @@ def call_requests(method, url, params=None, data=None, json=None, verify=True):
     while retry <= API_RETRY:
         try:
             resp = requests.request(method, url, params=params, data=data, json=json, headers=headers, verify=verify)
+            if not resp.ok:
+                time.sleep(retry * 2)
+                retry+=1
+                continue
         except requests.exceptions.ConnectionError:
             time.sleep(retry * 2)
             retry+=1
@@ -140,18 +164,17 @@ def get_run_result(run_id, field=None, default_value=None):
     return result
 
 def get_result_by_run(run_id, field=None, default_value=None):
-    logging.error(f'{" "} <-----   Entered Into get result by run   ----->')
     try:
         s3 = get_s3_client()
-        run_id= f'analytics-apps/json/{run_id}'
-        res_object = s3.get_object(Bucket=S3_BUCKET_NAME,Key=run_id)
+        run_id= f'analytics-apps/{ROUTE}/json/{run_id}'
+        res_object = s3.get_object(Bucket=BUCKET_NAME,Key=run_id)
         serializedObject = res_object['Body'].read()
         result = json.loads(serializedObject)
         if field:
             result = result.get(field, default_value)
         return result
     except Exception:
-        logging.error('<An error occurred (NoSuchKey) when calling the GetObject operation: The specified key does not exist>')
+        logger.error('An error occurred (NoSuchKey) when calling the GetObject operation: The specified key does not exist')
         pass
 
 
@@ -166,15 +189,15 @@ def get_run_params(run_id, field=None, default_value=None):
 def get_ses_client():
     return boto3.client('ses',
                         region_name=REGION_NAME,
-                        aws_access_key_id=AWS_ACCESS_KEY_ID,
-                        aws_secret_access_key=AWS_SECRET_ACCESS_KEY)
+                        aws_access_key_id=ACCESS_KEY_ID,
+                        aws_secret_access_key=SECRET_ACCESS_KEY)
 
 
 def get_s3_client():
     return boto3.client('s3',
                         region_name=REGION_NAME,
-                        aws_access_key_id=AWS_ACCESS_KEY_ID,
-                        aws_secret_access_key=AWS_SECRET_ACCESS_KEY)
+                        aws_access_key_id=ACCESS_KEY_ID,
+                        aws_secret_access_key=SECRET_ACCESS_KEY)
     
 
 def send_email(subject, from_email, to_emails, body, attachment=None):
@@ -211,35 +234,33 @@ def upload_to_s3(content, location):
     '''
     s3 = boto3.resource('s3',
                         region_name=REGION_NAME,
-                        aws_access_key_id=AWS_ACCESS_KEY_ID,
-                        aws_secret_access_key=AWS_SECRET_ACCESS_KEY)
-    object_url = f'https://{S3_BUCKET_NAME}.s3.{REGION_NAME}.amazonaws.com/{location}'
+                        aws_access_key_id=ACCESS_KEY_ID,
+                        aws_secret_access_key=SECRET_ACCESS_KEY)
+    object_url = f'https://{BUCKET_NAME}.s3.{REGION_NAME}.amazonaws.com/{location}'
 
     try:
-        s3.Bucket(S3_BUCKET_NAME).put_object(Body=content,
+        s3.Bucket(BUCKET_NAME).put_object(Body=content,
                                              Key=location)
         return object_url
     except Exception:
         pass
     
 
-def generate_pdf(analysis_run, app_name):
-    logging.error(f'{"Pdf"} <-----   Entered Into Pdf Generation Process   ----->')
+def generate_pdf(analysis_run):
+    logger.info('Entered into pdf generation process')
     url = os.getenv("PDF_SERVICE")
-    route = os.getenv("PLATFORM_ROUTE")
     # analysis_run = json.dumps(analysis_run)
     data = {
-        'domain': 'https://asura.opsramp.net',
-        'report': route,
+        'domain': BASE_API_URL,
+        'report': ROUTE,
         'run': analysis_run,
         'route': '/full-view',
         'token': get_token(),
-        'app_name': app_name,
         'size': 'A4'
     }
 
     res = requests.post(url, data=data).json()
-    logging.error(f'{res} <-----     Pdf Response     ----->')
+    logger.info('Pdf response is: %s', res)
     return res
 
 
